#!/bin/bash

# This helper script will handle deploying a MSK cluster
#
# /scripts/deploy-msk.sh
#

set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "iam_policy_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"

arnConfigMapName=${namingPrefix}-arn
terraform_get msk_cluster_arn arnValue
terraform_get msk_bootstrap_brokers mskBootstrapBrokers
terraform_get msk_zookeeper_connect_string mskZookeeperConnectString
terraform_get msk_bootstrap_brokers_sasl_iam mskBootstrapBrokersSaslIam
terraform_get msk_bootstrap_brokers_public_sasl_iam mskBootstrapBrokersPublicSaslIam

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}

EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

create_hostname_configmap ${namingPrefix}-endpoint ${appsNamespace} "--from-literal=bootstrapBrokers=${mskBootstrapBrokers}" "--from-literal=zookeeperConnectString=${mskZookeeperConnectString}" "--from-literal=bootstrapBrokersSaslIam=${mskBootstrapBrokersSaslIam}" "--from-literal=bootstrapBrokersPublicSaslIam=${mskBootstrapBrokersPublicSaslIam}"
create_hostname_configmap ${namingPrefix}-endpoint ${infraNamespace} "--from-literal=bootstrapBrokers=${mskBootstrapBrokers}" "--from-literal=zookeeperConnectString=${mskZookeeperConnectString}" "--from-literal=bootstrapBrokersSaslIam=${mskBootstrapBrokersSaslIam}" "--from-literal=bootstrapBrokersPublicSaslIam=${mskBootstrapBrokersPublicSaslIam}"
cprint "$0 done "
